@@ -15,7 +15,7 @@ unsafe impl GlobalAlloc for ZeroingAllocator {
 
     unsafe fn dealloc(&self, ptr: *mut u8, layout: Layout) {
         // TODO perhaps use volatile_set_memory when stabilized
-        libc::explicit_bzero(ptr.cast(), layout.size());
+        nix::libc::explicit_bzero(ptr.cast(), layout.size());
         System.dealloc(ptr, layout);
     }
 }
