@@ -1,12 +1,13 @@
-// SPDX-License-Identifier: GPL-3.0-or-later
+// SPDX-License-Identifier: MPL-2.0
 
 use std::path::Path;
+use std::pin::Pin;
 
 use anyhow::Result;
-use sodiumoxide::crypto::aead::xchacha20poly1305_ietf::Key;
 
 use crate::cli::key;
 use crate::cli::passphrase;
+use crate::crypto::chacha20::Key;
 use crate::database::Database;
 use crate::entries;
 use crate::header::Header;
@@ -17,7 +18,7 @@ pub fn open(database_path: &Path) -> Result<()> {
     repl::repl(database_path, &key)
 }
 
-fn read_key(database_path: &Path) -> Result<Key> {
+fn read_key(database_path: &Path) -> Result<Pin<Box<Key>>> {
     let database = Database::read(database_path)?;
     let header = Header::deserialize(&database.header)?;
 
