@@ -1,4 +1,4 @@
-// SPDX-License-Identifier: GPL-3.0-or-later
+// SPDX-License-Identifier: MPL-2.0
 
 use std::path::Path;
 
@@ -23,6 +23,6 @@ pub fn pass(database_path: &Path) -> Result<()> {
     let new_passphrase = passphrase::new_passphrase(&mut header);
     let new_key = key::derive_key(&new_passphrase, &header)?;
 
-    let new_database = entries::encrypt(&mut header, &entries, &new_key);
+    let new_database = entries::encrypt(&mut header, &entries, &new_key)?;
     new_database.overwrite(database_path)
 }
