@@ -4,19 +4,22 @@ use std::io::Write;
 
 use termion::input::TermRead;
 
-use crate::crypto::argon2;
+use crate::crypto::argon2::Salt;
 use crate::header::Header;
+use crate::wordlist;
 
 const NUM_WORDS: u32 = 6;
 
 pub fn new_passphrase(header: &mut Header) -> String {
-
-    let passphrase = (0..NUM_WORDS).map(|_| eff_wordlist::large::random_word()).collect::<Vec<_>>().join("-");
+    let passphrase = (0..NUM_WORDS)
+        .map(|_| wordlist::random_word())
+        .collect::<Vec<_>>()
+        .join("-");
     println!("The new passphrase for this database file is: {}", passphrase);
     println!("Remember this passphrase! It will not be displayed again.");
 
     // Every new passphrase gets a new salt
-    header.salt = argon2::gen_salt();
+    header.salt = Salt::generate();
 
     passphrase
 }
