@@ -1,8 +1,8 @@
 // SPDX-License-Identifier: MPL-2.0
 
+use std::fs;
 use std::fs::File;
 use std::fs::OpenOptions;
-use std::fs;
 use std::io::Read;
 use std::io::Write;
 use std::os::unix::fs::OpenOptionsExt;
@@ -11,8 +11,8 @@ use std::path::Path;
 use anyhow::{bail, Context, Result};
 
 use crate::header::Header;
-use crate::random::CharSet;
 use crate::random;
+use crate::random::CharSet;
 
 #[derive(Debug, PartialEq, Eq)]
 pub struct Database {
@@ -22,8 +22,8 @@ pub struct Database {
 
 impl Database {
     pub fn read(database_path: &Path) -> Result<Database> {
-        let mut file = File::open(database_path)
-            .with_context(|| format!("Unable to open file {}", database_path.display()))?;
+        let mut file =
+            File::open(database_path).with_context(|| format!("Unable to open file {}", database_path.display()))?;
 
         let mut content = Vec::<u8>::new();
         file.read_to_end(&mut content)
@@ -55,8 +55,13 @@ impl Database {
 
         self.write_database(&tempfile_path)?;
 
-        fs::rename(&tempfile_path, database_path)
-            .with_context(|| format!("Unable to rename {} to {}", tempfile_path.display(), database_path.display()))?;
+        fs::rename(&tempfile_path, database_path).with_context(|| {
+            format!(
+                "Unable to rename {} to {}",
+                tempfile_path.display(),
+                database_path.display()
+            )
+        })?;
 
         sync_parent_dir(database_path)
     }
@@ -69,29 +74,35 @@ impl Database {
             .open(path)
             .with_context(|| format!("Unable to open file {}", path.display()))?;
 
-        file.write_all(&self.header).with_context(|| format!("Unable to write to file {}", path.display()))?;
-        file.write_all(&self.ciphertext).with_context(|| format!("Unable to write to file {}", path.display()))?;
+        file.write_all(&self.header)
+            .with_context(|| format!("Unable to write to file {}", path.display()))?;
+        file.write_all(&self.ciphertext)
+            .with_context(|| format!("Unable to write to file {}", path.display()))?;
 
-        file.sync_all().with_context(|| format!("Unable to synchronise file {}", path.display()))
+        file.sync_all()
+            .with_context(|| format!("Unable to synchronise file {}", path.display()))
     }
 }
 
 fn sync_parent_dir(database_path: &Path) -> Result<()> {
-    let canon_path = database_path.canonicalize()
+    let canon_path = database_path
+        .canonicalize()
         .with_context(|| format!("Unable to find canonical path for {}", database_path.display()))?;
-    let parent_path = canon_path.parent()
+    let parent_path = canon_path
+        .parent()
         .with_context(|| format!("Unable to find parent directory of {}", canon_path.display()))?;
 
-    let parent_dir = File::open(parent_path)
-        .with_context(|| format!("Unable to open directory {}", parent_path.display()))?;
-    parent_dir.sync_all()
+    let parent_dir =
+        File::open(parent_path).with_context(|| format!("Unable to open directory {}", parent_path.display()))?;
+    parent_dir
+        .sync_all()
         .with_context(|| format!("Unable to synchronize directory {}", parent_path.display()))
 }
 
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::testfile::TestFile;
+    use assert_fs::NamedTempFile;
 
     fn gen_test_database() -> Database {
         Database {
@@ -102,47 +113,48 @@ mod tests {
 
     #[test]
     fn read_detects_too_short_header() {
-        let test_file = TestFile::new();
-        std::fs::write(&test_file.path, vec![0xAA; 10]).unwrap();
+        let test_file = NamedTempFile::new("test.napa").unwrap();
 
-        let result = Database::read(&test_file.path);
+        std::fs::write(test_file.path(), vec![0xAA; 10]).unwrap();
+
+        let result = Database::read(test_file.path());
         assert!(result.is_err());
     }
 
     #[test]
     fn read_write_roundtrips() {
-        let test_file = TestFile::new();
+        let test_file = NamedTempFile::new("test.napa").unwrap();
 
         let test_database = gen_test_database();
-        test_database.write_new(&test_file.path).unwrap();
+        test_database.write_new(test_file.path()).unwrap();
 
-        let read_database = Database::read(&test_file.path).unwrap();
+        let read_database = Database::read(test_file.path()).unwrap();
 
         assert_eq!(read_database, test_database);
     }
 
     #[test]
     fn write_new_fails_if_path_exists() {
-        let test_file = TestFile::new();
+        let test_file = NamedTempFile::new("test.napa").unwrap();
         let test_database = gen_test_database();
 
-        test_database.write_new(&test_file.path).unwrap();
+        test_database.write_new(test_file.path()).unwrap();
 
-        let result = test_database.write_new(&test_file.path);
+        let result = test_database.write_new(test_file.path());
         assert!(result.is_err());
     }
 
     #[test]
     fn can_overwrite_old_database() {
-        let test_file = TestFile::new();
+        let test_file = NamedTempFile::new("test.napa").unwrap();
 
         let mut test_database = gen_test_database();
-        test_database.write_new(&test_file.path).unwrap();
+        test_database.write_new(test_file.path()).unwrap();
 
         test_database.header[0] += 1;
-        test_database.overwrite(&test_file.path).unwrap();
+        test_database.overwrite(test_file.path()).unwrap();
 
-        let read_database = Database::read(&test_file.path).unwrap();
+        let read_database = Database::read(test_file.path()).unwrap();
 
         assert_eq!(read_database, test_database);
     }
