@@ -4,8 +4,8 @@ use std::collections::BTreeMap;
 
 use anyhow::{Context, Result};
 
-use crate::crypto::chacha20::Key;
 use crate::crypto::chacha20;
+use crate::crypto::chacha20::{Key, Nonce};
 use crate::crypto::padding;
 use crate::database::Database;
 use crate::header::Header;
@@ -20,7 +20,7 @@ pub fn encrypt(header: &mut Header, entries: &Entries, key: &Key) -> Result<Data
     padding::pad(&mut plaintext, BLOCKSIZE)?;
 
     // Each encryption gets a new nonce
-    header.nonce = chacha20::gen_nonce();
+    header.nonce = Nonce::generate();
     let header_bytes = header.serialize();
 
     let ciphertext = chacha20::encrypt(&plaintext, &header_bytes, &header.nonce, key)?;
@@ -95,8 +95,6 @@ fn deserialize_string(bytes: &[u8], i: &mut usize) -> String {
 mod tests {
     use super::*;
 
-    use crate::crypto::chacha20::KEYBYTES;
-
     #[test]
     fn string_serialization_roundtrips() {
         let strings = ["", "abc", "Hello world!", "平仮名", "😀😁"];
@@ -104,7 +102,7 @@ mod tests {
             let mut bytes = Vec::new();
             let mut i = 0;
             serialize_string(&mut bytes, string);
-            assert_eq!(*string, deserialize_string(&mut bytes, &mut i));
+            assert_eq!(*string, deserialize_string(&bytes, &mut i));
             assert_eq!(i, 4 + string.len());
         }
     }
@@ -126,26 +124,38 @@ mod tests {
 
     #[test]
     fn encryption_roundtrips() {
-        let key = Key([0xAA; KEYBYTES]);
+        let key = Key([0xAA; Key::SIZE]);
 
         let mut header = Header::default();
 
         let mut entries = Entries::new();
-        assert_eq!(entries, decrypt(&encrypt(&mut header, &entries, &key).unwrap(), &header, &key).unwrap());
+        assert_eq!(
+            entries,
+            decrypt(&encrypt(&mut header, &entries, &key).unwrap(), &header, &key).unwrap()
+        );
 
         entries.insert("".to_string(), "".to_string());
-        assert_eq!(entries, decrypt(&encrypt(&mut header, &entries, &key).unwrap(), &header, &key).unwrap());
+        assert_eq!(
+            entries,
+            decrypt(&encrypt(&mut header, &entries, &key).unwrap(), &header, &key).unwrap()
+        );
 
         entries.insert("Hello".to_string(), "World".to_string());
-        assert_eq!(entries, decrypt(&encrypt(&mut header, &entries, &key).unwrap(), &header, &key).unwrap());
+        assert_eq!(
+            entries,
+            decrypt(&encrypt(&mut header, &entries, &key).unwrap(), &header, &key).unwrap()
+        );
 
         entries.insert("平仮名".to_string(), "😀😁".to_string());
-        assert_eq!(entries, decrypt(&encrypt(&mut header, &entries, &key).unwrap(), &header, &key).unwrap());
+        assert_eq!(
+            entries,
+            decrypt(&encrypt(&mut header, &entries, &key).unwrap(), &header, &key).unwrap()
+        );
     }
 
     #[test]
     fn database_header_corruption_is_detected() {
-        let key = Key([0xAA; KEYBYTES]);
+        let key = Key([0xAA; Key::SIZE]);
         let mut header = Header::default();
 
         let entries = Entries::new();
@@ -158,7 +168,7 @@ mod tests {
 
     #[test]
     fn database_ciphertext_corruption_is_detected() {
-        let key = Key([0xAA; KEYBYTES]);
+        let key = Key([0xAA; Key::SIZE]);
         let mut header = Header::default();
 
         let entries = Entries::new();
