@@ -15,11 +15,7 @@ pub fn del(name: &str, database_path: &Path, key: &Key) -> Result<()> {
     util::write_database(database_path, &mut header, &entries, key)
 }
 
-fn del_impl(
-    name: &str,
-    entries: &mut Entries,
-    input: &mut impl BufRead,
-) {
+fn del_impl(name: &str, entries: &mut Entries, input: &mut impl BufRead) {
     if entries.contains_key(name) {
         let prompt = format!("Are you sure you want to delete {}? [y/N] ", name);
         let delete = util::confirm_prompt(&prompt, input);
