@@ -15,12 +15,7 @@ pub fn do_move(source_name: &str, dest_name: &str, database_path: &Path, key: &K
     util::write_database(database_path, &mut header, &entries, key)
 }
 
-fn do_move_impl(
-    source_name: &str,
-    dest_name: &str,
-    entries: &mut Entries,
-    input: &mut impl BufRead,
-) {
+fn do_move_impl(source_name: &str, dest_name: &str, entries: &mut Entries, input: &mut impl BufRead) {
     if !entries.contains_key(source_name) {
         println!("Error: entry for {} does not exist.", source_name);
         return;
