@@ -16,11 +16,7 @@ pub fn edit(name: &str, database_path: &Path, key: &Key) -> Result<()> {
     util::write_database(database_path, &mut header, &entries, key)
 }
 
-fn edit_impl(
-    name: &str,
-    entries: &mut Entries,
-    edit: fn(&str) -> Result<String>,
-) -> Result<()> {
+fn edit_impl(name: &str, entries: &mut Entries, edit: fn(&str) -> Result<String>) -> Result<()> {
     if let Some(content) = entries.get_mut(name) {
         let new_content = edit(content)?;
         if new_content == *content {
