@@ -7,8 +7,8 @@ use anyhow::Result;
 
 use crate::crypto::chacha20::Key;
 use crate::entries::Entries;
-use crate::random::CharSet;
 use crate::random;
+use crate::random::CharSet;
 use crate::repl::util;
 
 const PASSWORD_PREFIX: &str = "password:";
@@ -49,12 +49,7 @@ pub fn gen(name: &str, length: u32, charset: CharSet, database_path: &Path, key:
     util::write_database(database_path, &mut header, &entries, key)
 }
 
-fn gen_impl(
-    name: &str,
-    new_password: &str,
-    entries: &mut Entries,
-    input: &mut impl BufRead,
-) {
+fn gen_impl(name: &str, new_password: &str, entries: &mut Entries, input: &mut impl BufRead) {
     if let Some(content) = entries.get_mut(name) {
         if find_password(content).is_some() {
             let prompt = format!("Password for {} already exists. Overwrite it? [y/N] ", name);
@@ -91,25 +86,28 @@ mod tests {
     #[test]
     fn find_password_returns_none_if_no_password() {
         let content = "no password here";
-        assert!(find_password(&content).is_none());
+        assert!(find_password(content).is_none());
     }
 
     #[test]
     fn find_password_returns_first_password() {
         let content = "first line\npassword: first password  \npassword: second password";
-        assert_eq!(find_password(&content), Some("first password".to_string()));
+        assert_eq!(find_password(content), Some("first password".to_string()));
     }
 
     #[test]
     fn replace_password_does_nothing_if_no_password_found() {
         let content = "no password here";
-        assert_eq!(replace_password(&content, "new password"), content);
+        assert_eq!(replace_password(content, "new password"), content);
     }
 
     #[test]
     fn replace_password_replaces_first_password() {
         let content = "first line\npassword: first password   \npassword: second password";
-        assert_eq!(replace_password(&content, "new password"), "first line\npassword: new password\npassword: second password");
+        assert_eq!(
+            replace_password(content, "new password"),
+            "first line\npassword: new password\npassword: second password"
+        );
     }
 
     #[test]
