@@ -14,51 +14,42 @@ use std::io::Write;
 use std::path::Path;
 
 use anyhow::Result;
-use rustyline::Editor;
+use clap::Parser;
 use rustyline::error::ReadlineError;
-use structopt::StructOpt;
-use structopt::clap::AppSettings;
+use rustyline::Editor;
 
 use crate::crypto::chacha20::Key;
 use crate::random::CharSet;
 
-#[derive(Debug, StructOpt)]
-#[structopt(setting(AppSettings::NoBinaryName))]
+#[derive(Debug, Parser)]
+#[clap(no_binary_name = true)]
 pub enum Repl {
-    #[structopt(about = "List the existing entries in the database")]
-    List,
-    #[structopt(about = "Edit the entry using $EDITOR")]
-    Edit {
-        entry_name: String
+    #[clap(about = "List the entry names in the database")]
+    List {
+        #[clap(help = "Only list names that contain the given substring")]
+        substr: Option<String>,
     },
-    #[structopt(about = "Print the contents of the entry")]
-    Show {
-        entry_name: String
-    },
-    #[structopt(about = "Delete the entry")]
-    Del {
-        entry_name: String
-    },
-    #[structopt(about = "Rename the entry")]
-    Move {
-        old_name: String,
-        new_name: String,
-    },
-    #[structopt(about = "Generate a new password for the entry")]
+    #[clap(about = "Edit the entry using $EDITOR")]
+    Edit { entry_name: String },
+    #[clap(about = "Print the contents of the entry")]
+    Show { entry_name: String },
+    #[clap(about = "Delete the entry")]
+    Del { entry_name: String },
+    #[clap(about = "Rename the entry")]
+    Move { old_name: String, new_name: String },
+    #[clap(about = "Generate a new password for the entry")]
     Gen {
         entry_name: String,
-        #[structopt(short, long, default_value = "25")]
+        #[clap(short, long, default_value = "25")]
         length: u32,
-        #[structopt(short, long, possible_values = &CharSet::variants(), default_value = "alnum")]
+        #[clap(arg_enum, short, long, default_value = "alnum")]
         charset: CharSet,
     },
-    #[structopt(about = "Copy the entry password to the clipboard")]
-    Clip {
-        entry_name: String,
-    },
-    #[structopt(about = "Clear the screen")]
+    #[clap(about = "Copy the entry password to the clipboard")]
+    Clip { entry_name: String },
+    #[clap(about = "Clear the screen")]
     Clear,
-    #[structopt(about = "Close the database")]
+    #[clap(about = "Close the database")]
     Exit,
 }
 
@@ -67,7 +58,7 @@ impl Repl {
         let mut exit = false;
 
         match self {
-            Repl::List => list::list(database_path, key)?,
+            Repl::List { substr } => list::list(substr, database_path, key)?,
 
             Repl::Edit { entry_name } => edit::edit(entry_name, database_path, key)?,
             Repl::Show { entry_name } => show::show(entry_name, database_path, key)?,
@@ -76,7 +67,11 @@ impl Repl {
 
             Repl::Clear => clear::clear(),
 
-            Repl::Gen { entry_name, length, charset } => gen::gen(entry_name, *length, *charset, database_path, key)?,
+            Repl::Gen {
+                entry_name,
+                length,
+                charset,
+            } => gen::gen(entry_name, *length, *charset, database_path, key)?,
             Repl::Clip { entry_name } => clip::clip(entry_name, database_path, key)?,
 
             Repl::Exit => exit = true,
@@ -109,19 +104,19 @@ pub fn repl(database_path: &Path, key: &Key) -> Result<()> {
 }
 
 fn process_line(database_path: &Path, key: &Key, line: &str) -> Result<bool> {
-    let commands = line
-        .split_whitespace()
-        .map(String::from)
-        .collect::<Vec<String>>();
+    let commands = line.split_whitespace().map(String::from).collect::<Vec<String>>();
 
     if commands.is_empty() {
         return Ok(false);
     }
 
-    let result = Repl::from_iter_safe(commands);
+    let result = Repl::try_parse_from(commands);
 
     match result {
         Ok(args) => args.run(database_path, key),
-        Err(error) => { println!("{}", error.message); Ok(false) }
+        Err(error) => {
+            println!("{}", error);
+            Ok(false)
+        }
     }
 }
