@@ -8,8 +8,8 @@ use anyhow::Result;
 
 use crate::crypto::chacha20::Key;
 use crate::database::Database;
-use crate::entries::Entries;
 use crate::entries;
+use crate::entries::Entries;
 use crate::header::Header;
 
 pub fn read_database(database_path: &Path, key: &Key) -> Result<(Header, Entries)> {
@@ -38,23 +38,23 @@ pub fn confirm_prompt(prompt: &str, input: &mut impl BufRead) -> bool {
 mod tests {
     use super::*;
 
-    use crate::crypto::chacha20::KEYBYTES;
+    use assert_fs::NamedTempFile;
+
     use crate::entries::Entries;
-    use crate::testfile::TestFile;
 
     #[test]
     fn read_write_database_roundtrips() {
-        let key = Key([0xAA; KEYBYTES]);
+        let key = Key([0xAA; Key::SIZE]);
         let mut header = Header::default();
 
         let mut entries = Entries::new();
         entries.insert("Hello".to_string(), "World".to_string());
         entries.insert("平仮名".to_string(), "😀😁".to_string());
 
-        let test_file = TestFile::new();
-        write_database(&test_file.path, &mut header, &entries, &key).unwrap();
+        let test_file = NamedTempFile::new("test.napa").unwrap();
+        write_database(test_file.path(), &mut header, &entries, &key).unwrap();
 
-        let (new_header, new_entries) = read_database(&test_file.path, &key).unwrap();
+        let (new_header, new_entries) = read_database(test_file.path(), &key).unwrap();
 
         assert_eq!(header, new_header);
         assert_eq!(entries, new_entries);
