@@ -9,8 +9,8 @@ use anyhow::{Context, Result};
 use nix::sys::stat;
 use nix::unistd;
 
-use crate::random::CharSet;
 use crate::random;
+use crate::random::CharSet;
 
 pub struct TempFile {
     pub path: PathBuf,
@@ -58,8 +58,7 @@ impl TempFile {
     }
 
     pub fn read(&self) -> Result<String> {
-        std::fs::read_to_string(&self.path)
-            .with_context(|| format!("Unable to read from file {}", self.path.display()))
+        std::fs::read_to_string(&self.path).with_context(|| format!("Unable to read from file {}", self.path.display()))
     }
 
     pub fn remove(self) -> Result<()> {
